#!/usr/bin/python3

import hashlib
import os
import subprocess
import sys
import tempfile


def get_sum(fname):
    with open(fname, "rb") as fh:
        h = hashlib.md5(fh.read())
    return h.digest()


def process(lines, fname, noop):
    # save the lines in the file
    with open(fname, "wt", encoding="utf8") as fh:
        fh.writelines(lines)
    md5_pre = get_sum(fname)

    # offer the file to the user
    editor = os.environ["EDITOR"]
    if editor.startswith("gvim"):
        editor += ' -c "set nowrap"'
    subprocess.call("{} {}".format(editor, fname), shell=True)

    if noop:
        return

    # if untouched, quit
    md5_post = get_sum(fname)
    if md5_pre == md5_post:
        print("WARNING: file not modified! quitting")
        return

    # execute it
    subprocess.call("bash {}".format(fname), shell=True)


def main(direct, intact, noop):
    archs = sorted(os.listdir(direct))
    if not archs:
        print("WARNING: nada a convertir en", repr(direct))
        return

    maxlargo = max(len(x) for x in archs) + len(direct) + 3
    lines = []
    for arch in archs:
        arch = os.path.join(direct, arch)
        arch = '"%s"' % arch.replace('"', '\\"')
        if intact:
            dest = arch
        else:
            dest = arch.lower()
        line = 'mv %-*s %s\n' % (maxlargo, arch, dest)
        lines.append(line)

    _, fname = tempfile.mkstemp()
    try:
        process(lines, fname, noop)
    finally:
        if not noop:
            os.remove(fname)


if __name__ == "__main__":
    if "--intact" in sys.argv:
        sys.argv.remove("--intact")
        intact = True
    else:
        intact = False

    if "--noop" in sys.argv:
        sys.argv.remove("--noop")
        noop = True
    else:
        noop = False

    if len(sys.argv) != 2:
        dirpath = '.'
    else:
        dirpath = sys.argv[1]

    main(dirpath, intact, noop)
